@@ -28,6 +28,7 @@
 
 #include "eog-error-message-area.h"
 #include "eog-image.h"
+#include "eog-util.h"
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -171,7 +172,7 @@ eog_image_load_error_message_area_new (const gchar  *caption,
 	error_message = g_strdup_printf (_("Could not load image '%s'."),
 					 pango_escaped_caption);
 
-	message_details = g_strdup (error->message);
+	message_details = eog_util_make_valid_utf8 (error->message);
 
 	message_area = create_error_message_area (error_message,
 						  message_details,
@@ -213,7 +214,7 @@ eog_image_save_error_message_area_new (const gchar  *caption,
 	error_message = g_strdup_printf (_("Could not save image '%s'."),
 					 pango_escaped_caption);
 
-	message_details = g_strdup (error->message);
+	message_details = eog_util_make_valid_utf8 (error->message);
 
 	message_area = create_error_message_area (error_message,
 						  message_details,
