@@ -696,10 +696,32 @@ eog_image_apply_display_profile (EogImage *img, cmsHPROFILE screen)
 	if (screen == NULL) return;
 
 	if (priv->profile == NULL) {
-		/* Assume sRGB color space for images without ICC profile */
-		eog_debug_message (DEBUG_LCMS, "Image has no ICC profile. "
-		                   "Assuming sRGB.");
-		priv->profile = cmsCreate_sRGBProfile ();
+		/* Check whether GdkPixbuf was able to extract a profile */
+		const char* data = gdk_pixbuf_get_option (priv->image,
+		                                          "icc-profile");
+
+		if(data) {
+			gsize   profile_size = 0;
+			guchar *profile_data = g_base64_decode(data,
+			                                       &profile_size);
+
+			if (profile_data && profile_size > 0) {
+				eog_debug_message (DEBUG_LCMS,
+				                   "Using ICC profile "
+				                   "extracted by GdkPixbuf");
+				priv->profile =
+					cmsOpenProfileFromMem(profile_data,
+					                      profile_size);
+				g_free(profile_data);
+			}
+		}
+
+		if(priv->profile == NULL) {
+			/* Assume sRGB color space for images without ICC profile */
+			eog_debug_message (DEBUG_LCMS, "Image has no ICC profile. "
+					   "Assuming sRGB.");
+			priv->profile = cmsCreate_sRGBProfile ();
+		}
 	}
 
 	/* TODO: support other colorspaces than RGB */
@@ -1141,7 +1163,7 @@ eog_image_real_load (EogImage *img,
 					eog_image_set_xmp_data (img, md_reader);
 #endif
 					set_metadata = FALSE;
-                                        priv->metadata_status = EOG_IMAGE_METADATA_READY;
+					priv->metadata_status = EOG_IMAGE_METADATA_READY;
 				}
 
 				if (data2read == EOG_IMAGE_DATA_EXIF)
@@ -1158,7 +1180,10 @@ eog_image_real_load (EogImage *img,
 	if (read_image_data || read_only_dimension) {
 #ifdef HAVE_RSVG
 		if (use_rsvg) {
-			rsvg_handle_close (priv->svg, error);
+			/* Ignore the error if loading failed earlier
+			 * as the error will already be set in that case */
+			rsvg_handle_close (priv->svg,
+			                   (failed ? NULL : error));
 		} else
 #endif
 		if (failed) {
@@ -1169,8 +1194,8 @@ eog_image_real_load (EogImage *img,
 				 * images as well. */
 				g_clear_error (error);
 			}
-	        }
-        }
+		}
+	}
 
 	g_free (buffer);
 
